==> libjogl2-java_2.2.4+dfsg.orig.tar.xz: jogl-v2.2.4/src/newt/native/ScreenMode.h <==
/**
 * Copyright 2011 JogAmp Community. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are
 * permitted provided that the following conditions are met:
 * 
 *    1. Redistributions of source code must retain the above copyright notice, this list of
 *       conditions and the following disclaimer.
 * 
 *    2. Redistributions in binary form must reproduce the above copyright notice, this list
 *       of conditions and the following disclaimer in the documentation and/or other materials
 *       provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY JogAmp Community ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL JogAmp Community OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are those of the
 * authors and should not be interpreted as representing official policies, either expressed
 * or implied, of JogAmp Community.
 */

/**
 * WARNING: must be synced with com.jogamp.newt.util.ScreenModeUtil#streamIn*(int[])
 */

#ifndef _SCREEN_MODE_H
#define _SCREEN_MODE_H

#define NUM_RESOLUTION_PROPERTIES     2   /* width, height */
#define NUM_SURFACE_SIZE_PROPERTIES   1   /* bpp */
#define NUM_SIZEANDRATE_PROPERTIES    2   /* refresh-rate, flags */
#define NUM_MONITOR_MODE_PROPERTIES   2   /* id, rotation */

#define NUM_MONITOR_MODE_PROPERTIES_ALL  8  /* count + the above */

#define MIN_MONITOR_DEVICE_PROPERTIES 15   /* count + id, ScreenSizeMM[width, height], rotated Viewport pixel-units, rotated Viewport pixel-units, currentMonitorModeId, rotation, supportedModeId+ */
                                           /* Viewport := [x, y, width, height] (4 elements) */

#define FLAG_INTERLACE      ( 1 << 0 )
#define FLAG_DOUBLESCAN     ( 1 << 1 )

#endif

==> libjogl2-java_2.5.0+dfsg.orig.tar.xz: jogl-v2.5.0/src/newt/native/ScreenMode.h <==
/**
 * Copyright 2011 JogAmp Community. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are
 * permitted provided that the following conditions are met:
 * 
 *    1. Redistributions of source code must retain the above copyright notice, this list of
 *       conditions and the following disclaimer.
 * 
 *    2. Redistributions in binary form must reproduce the above copyright notice, this list
 *       of conditions and the following disclaimer in the documentation and/or other materials
 *       provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY JogAmp Community ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL JogAmp Community OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are those of the
 * authors and should not be interpreted as representing official policies, either expressed
 * or implied, of JogAmp Community.
 */

/**
 * WARNING: must be synced with com.jogamp.newt.util.ScreenModeUtil#streamIn*(int[])
 */

#ifndef _SCREEN_MODE_H
#define _SCREEN_MODE_H

#define NUM_RESOLUTION_PROPERTIES     2   /* width, height */
#define NUM_SURFACE_SIZE_PROPERTIES   1   /* bpp */
#define NUM_SIZEANDRATE_PROPERTIES    2   /* refresh-rate, flags */
#define NUM_MONITOR_MODE_PROPERTIES   2   /* id, rotation */

#define NUM_MONITOR_MODE_PROPERTIES_ALL  8  /* count + the above */

#define MIN_MONITOR_DEVICE_PROPERTIES 17   /* count + id + isClone + isPrimary, 
                                              ScreenSizeMM[width, height], 
                                              rotated Viewport pixel-units, 
                                              rotated Viewport pixel-units, 
                                              currentMonitorModeId, 
                                              rotation, 
                                              supportedModeId+
                                              
                                              with Viewport := [x, y, width, height] (4 elements) 
                                            */

#define FLAG_INTERLACE      ( 1 << 0 )
#define FLAG_DOUBLESCAN     ( 1 << 1 )

#endif
